@@ -40,8 +40,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
 import openid
-import openid.extensions.ax
-import openid.extensions.sreg
+from openid.extensions import ax, sreg
 from openid.store import filestore
 from openid.consumer import consumer
 import util
@@ -70,7 +69,7 @@ class CS50:
         
         # simple registration fields
         if len(fields) > 0:
-            sreg_request = sreg.SRegRequest(optional=fields, required=['key'])
+            sreg_request = sreg.SRegRequest(optional=fields, required=None)
             auth_request.addExtension(sreg_request)
             
         # attribute exchange fields
@@ -81,7 +80,7 @@ class CS50:
             auth_request.addExtension(ax_request)
         
         # generate url for direction
-        return auth_request.redirect_url(trust_root, return_to)
+        return auth_request.redirectURL(trust_root, return_to)
         
     """
     If user was authenticated (at URL returned by getLoginUrl),
@@ -91,11 +90,12 @@ class CS50:
     @param  directory   Path to directory used to store state
     @param  return_to   URL to which CS50 ID returned user
     @param  request     A Django Request object we can grab parameters from  
+    @param  view        The view function we call this function from
          
     @return user as associative array, or false if failed
     """
     @staticmethod
-    def getUser(directory, return_to, request):
+    def getUser(directory, return_to, request, view):
         user = {}
         
         # clean parameters from the request URL to ensure Janrain's lib works
@@ -104,11 +104,11 @@ class CS50:
             request_args.update(util.normalDict(request.POST))
 
         if request_args:
-            c = getConsumer(request)
+            c = consumer.Consumer(request.session, util.getOpenIDStore(directory, 'c_'))
             
         # Get a response object indicating the result of the OpenID
         # protocol.
-        return_to = util.getViewURL(request, getUser)
+        return_to = util.getViewURL(request, view)
         response = c.complete(request_args, return_to)
         
         if response.status == consumer.SUCCESS: 
